@@ -1,6 +1,4 @@
 package t::Bridge;
-use strict;
-use warnings;
 
 sub my_lower {
     my $context = shift;
@@ -16,9 +14,10 @@ sub combine {
     return join ' ', map $_->value, @_;
 }
 
-sub parse_testml {
+sub compile_testml {
     my $context = shift;
-    TestML::Parser->parse($context->value);
+    require TestML::Compiler;
+    TestML::Compiler->new->compile($context->value);
 }
 
 sub msg {
@@ -26,4 +25,16 @@ sub msg {
     return $context->value;
 }
 
+sub f1 {
+    my $context = shift;
+    my $num = shift->value;
+    return $num * 42 + $num;
+}
+
+sub f2 {
+    my $context = shift;
+    my $num = shift->value;
+    return $num * $num + $num;
+}
+
 1;
